@@ -1,21 +1,23 @@
 #' @title Extracts Imputed Datasets
 #'
+#' @name complete
+#'
 #' @rdname complete
 #'
 #' @aliases complete complete.mimids complete.wimids
 #'
-#' @param object This argument specifies an object of the \code{mids}, \code{mimids}, or \code{wimids} class.
+#' @param data This argument specifies an object of the \code{mimids} or \code{wimids} class.
 #' @param n This argument specifies the imputed dataset number, intended to extract its data, or an action. The input must be a positive integer or a keyword. The keywords include \code{"all"} (produces a \code{mild} object of the imputed datasets), \code{"long"} (produces a dataset with imputed datasets stacked vertically), and \code{"broad"} (produces a dataset with imputed datasets stacked horizontally). The default is \code{1}.
 #' @param include This argument specifies whether the original data with the missing values should be included. The input must be a logical value. The default is \code{FALSE}.
 #' @param mild This argument specifies whether the return value should be an object of \code{mild} class. Please note that setting \code{mild = TRUE} overrides \code{n} keywords \code{"long"}, \code{"broad"}, and \code{"repeated"}. The default is \code{FALSE}.
-#' @param all This argument specifies whether to include observations with a zero estimated weight (only for \code{mimids} or \code{wimids} objects). The default is \code{TRUE}.
+#' @param all This argument specifies whether to include observations with a zero estimated weight. The default is \code{TRUE}.
 #' @param ... Additional arguments to be passed to the function.
 #'
-#' @description \code{complete()} function extracts data from an object of the \code{mids}, \code{mimids}, or \code{wimids} class.
+#' @description \code{complete()} function extracts data from an object of the \code{mimids} or \code{wimids} class.
 #'
-#' @details The datasets within the \code{mids}, \code{mimids}, or \code{wimids} class objects are extracted.
+#' @details The datasets within the \code{mimids} or \code{wimids} class objects are extracted.
 #'
-#' @return This function returns the imputed dataset within \code{mids}, \code{mimids}, or \code{wimids} class objects.
+#' @return This function returns the imputed dataset within \code{mimids} or \code{wimids} class objects.
 #'
 #' @seealso \code{\link[=mimids]{mimids}}
 #' @seealso \code{\link[=wimids]{wimids}}
@@ -24,7 +26,9 @@
 #'
 #' @references Stef van Buuren and Karin Groothuis-Oudshoorn (2011). \code{mice}: Multivariate Imputation by Chained Equations in \code{R}. \emph{Journal of Statistical Software}, 45(3): 1-67. \url{https://www.jstatsoft.org/v45/i03/}
 #'
-#' @export
+#' @importFrom mice complete
+#'
+#' @export complete
 #'
 #' @examples \donttest{#Loading the dataset
 #' data(osteoarthritis)
@@ -41,49 +45,11 @@
 #' #Extracting the first imputed dataset
 #' matched.dataset.1 <- complete(matched.datasets, n = 1)}
 
-complete <- function(object, n = 1, include = FALSE, mild = FALSE, all = TRUE, ...) {
+#' @method complete mimids
+#'
+#' @export
 
-  #External function
-  #S3 method
-
-  #Based on: The mice::complete()
-  #URL: <https://cran.r-project.org/package=mice>
-  #URL: <https://github.com/stefvanbuuren/mice>
-  #URL: <https://cran.r-project.org/web/packages/mice/mice.pdf>
-  #URL: <https://www.jstatsoft.org/article/view/v045i03/v45i03.pdf>
-  #Authors: Stef van Buuren et al.
-  #Changes: Some
-
-  UseMethod("complete")
-}
-
-complete.mids <- function(object, n = 1L, include = FALSE, mild = FALSE, all = TRUE, ...) {
-
-  #External function
-  #S3 method
-
-  #Based on: The mice::complete()
-  #URL: <https://cran.r-project.org/package=mice>
-  #URL: <https://github.com/stefvanbuuren/mice>
-  #URL: <https://cran.r-project.org/web/packages/mice/mice.pdf>
-  #URL: <https://www.jstatsoft.org/article/view/v045i03/v45i03.pdf>
-  #Authors: Stef van Buuren et al.
-  #Changes: Some
-
-  #Importing functions
-  #' @importFrom mice is.mids complete
-  mice::is.mids
-  mice::complete
-  #' @export
-
-  #mids
-  if (mice::is.mids(object)) {
-    output <- mice::complete(data = object, action = n, include = include, mild = mild, ...)
-    return(output)
-  }
-}
-
-complete.mimids <- function(object, n = 1, include = FALSE, mild = FALSE, all = TRUE, ...) {
+complete.mimids <- function(data, n = 1, include = FALSE, mild = FALSE, all = TRUE, ...) {
 
   #External function
   #S3 method
@@ -99,7 +65,7 @@ complete.mimids <- function(object, n = 1, include = FALSE, mild = FALSE, all =
   #' @export
 
   #Polishing variables
-  data <- object
+  object <- data
   action <- n
   m <- as.integer(data$object$m)
 
@@ -161,7 +127,13 @@ complete.mimids <- function(object, n = 1, include = FALSE, mild = FALSE, all =
   }
 }
 
-complete.wimids <- function(object, n = 1, include = FALSE, mild = FALSE, all = TRUE, ...) {
+#' @rdname complete
+#'
+#' @method complete wimids
+#'
+#' @export
+
+complete.wimids <- function(data, n = 1, include = FALSE, mild = FALSE, all = TRUE, ...) {
 
   #External function
   #S3 method
@@ -177,7 +149,7 @@ complete.wimids <- function(object, n = 1, include = FALSE, mild = FALSE, all =
   #' @export
 
   #Polishing variables
-  data <- object
+  object <- data
   action <- n
   m <- as.integer(data$object$m)
 
